@@ -30,14 +30,14 @@ private Q_SLOTS:
     void cleanupTestCase();
 
     void testExcutableExactMatch();
-    void testChromeAppsRelevance();
     void testKonsoleVsYakuakeComment();
     void testSystemSettings();
     void testSystemSettings2();
     void testCategories();
     void testJumpListActions();
     void testINotifyUsage();
-    void testChromiumPWA();
+    void testSpecialArgs();
+    void testEnv();
 };
 
 void ServiceRunnerTest::initTestCase()
@@ -82,36 +82,6 @@ void ServiceRunnerTest::testExcutableExactMatch()
     }));
 }
 
-void ServiceRunnerTest::testChromeAppsRelevance()
-{
-    ServiceRunner runner(this, KPluginMetaData(), QVariantList());
-    Plasma::RunnerContext context;
-    context.setQuery(QStringLiteral("chrome"));
-
-    runner.match(context);
-
-    bool chromeFound = false;
-    bool signalFound = false;
-    const auto matches = context.matches();
-    for (const auto &match : matches) {
-        qDebug() << "matched" << match.text();
-        if (!match.text().contains(QLatin1String("ServiceRunnerTest"))) {
-            continue;
-        }
-
-        if (match.text() == QLatin1String("Google Chrome ServiceRunnerTest")) {
-            QCOMPARE(match.relevance(), 0.8);
-            chromeFound = true;
-        } else if (match.text() == QLatin1String("Signal ServiceRunnerTest")) {
-            // Rates lower because it doesn't have it in the name.
-            QCOMPARE(match.relevance(), 0.7);
-            signalFound = true;
-        }
-    }
-    QVERIFY(chromeFound);
-    QVERIFY(signalFound);
-}
-
 void ServiceRunnerTest::testKonsoleVsYakuakeComment()
 {
     // Yakuake has konsole mentioned in comment, should be rated lower.
@@ -286,43 +256,33 @@ void ServiceRunnerTest::testINotifyUsage()
 
     QVERIFY(inotifyCountCool);
 }
-void ServiceRunnerTest::testChromiumPWA()
+
+void ServiceRunnerTest::testSpecialArgs()
 {
     ServiceRunner runner(this, KPluginMetaData(), QVariantList());
     Plasma::RunnerContext context;
 
-    context.setQuery(QStringLiteral("meet"));
+    context.setQuery(QStringLiteral("kpat"));
     runner.match(context);
+    auto matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        // Should have no -qwindowtitle at the end. Because we use DesktopExecParser, we have a "true" as an exec which is available on all systems
+        return match.id().endsWith(QLatin1String("/bin/true"));
+    }));
+}
 
-    {
-        const QLatin1String pwaDesktopFile("chrome-kjgfgldnnfoeklkmfkjfagphfepbbdan-Default");
-        const auto matches = context.matches();
+void ServiceRunnerTest::testEnv()
+{
+    ServiceRunner runner(this, KPluginMetaData(), QVariantList());
+    Plasma::RunnerContext context;
 
-        const bool hasAtLeastOneMatch = matches.size() >= 1;
-        QVERIFY(hasAtLeastOneMatch);
-        const bool isGoogleMeetOrUsrFile = std::any_of(matches.begin(), matches.end(), [pwaDesktopFile](const Plasma::QueryMatch &match) {
-            const auto service = KService::serviceByStorageId(match.data().toUrl().path());
-            return service->entryPath().startsWith(QLatin1String("/usr/")) || service->desktopEntryName() == pwaDesktopFile;
-        });
-        QVERIFY(isGoogleMeetOrUsrFile);
-        const bool hasGoogleMeet = std::any_of(matches.begin(), matches.end(), [pwaDesktopFile](const Plasma::QueryMatch &match) {
-            return KService::serviceByStorageId(match.data().toUrl().path())->desktopEntryName() == pwaDesktopFile;
-        });
-        QVERIFY(hasGoogleMeet);
-    }
-
-    context.reset();
-    context.setQuery(QStringLiteral("dan"));
+    context.setQuery(QStringLiteral("audacity"));
     runner.match(context);
-
-    {
-        const auto matches = context.matches();
-        const bool isOnlyUsrFiles = std::all_of(matches.begin(), matches.end(), [](const Plasma::QueryMatch &match) {
-            const auto service = KService::serviceByStorageId(match.data().toUrl().path());
-            return service->entryPath().startsWith(QLatin1String("/usr/"));
-        });
-        QVERIFY(isOnlyUsrFiles);
-    }
+    auto matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        // Because we use DesktopExecParser, we have a "true" as an exec which is available on all systems
+        return match.id().endsWith(QLatin1String("/bin/true"));
+    }));
 }
 
 QTEST_MAIN(ServiceRunnerTest)
